'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');

const getNpmCommand = (ctx) => {
  const npm = process.platform === "win32" ? "npm.cmd" : "npm";
  ctx.logger.info(
    `OS platform is ${process.platform}, using '${npm}' as command`
  );
  return npm;
};

function createNpmExecAction() {
  return pluginScaffolderBackend.createTemplateAction({
    id: "npm:exec",
    description: "Runs npm exec with the given arguments in the task workspace directory",
    supportsDryRun: true,
    schema: {
      input: {
        type: "object",
        required: ["arguments"],
        properties: {
          arguments: {
            title: "Arguments",
            description: "The arguments to pass to the npm exec command",
            type: "array",
            items: {
              type: "string"
            }
          }
        }
      }
    },
    async handler(ctx) {
      try {
        console.log(`Running npm exec in ${ctx.workspacePath}`);
        ctx.logger.info(`Running npm exec in ${ctx.workspacePath}`);
        ctx.logger.info(`Input: ${ctx.input.arguments}`);
        const npm = getNpmCommand(ctx);
        await pluginScaffolderBackend.executeShellCommand({
          command: npm,
          args: ["exec", ...ctx.input.arguments],
          logStream: ctx.logStream,
          options: { cwd: ctx.workspacePath }
        });
        console.log("Done running npm exec");
        ctx.logger.info(`Done running npm exec`);
      } catch (err) {
        console.error(err);
        ctx.logger.error(err);
        throw err;
      }
    }
  });
}

function createNpmInitAction() {
  return pluginScaffolderBackend.createTemplateAction({
    id: "npm:init",
    description: "Runs npm init with defaults set in the task workspace directory",
    async handler(ctx) {
      try {
        console.log(`Running npm init in ${ctx.workspacePath}`);
        ctx.logger.info(`Running npm init in ${ctx.workspacePath}`);
        const npm = getNpmCommand(ctx);
        await pluginScaffolderBackend.executeShellCommand({
          command: npm,
          args: ["init", "-y"],
          logStream: ctx.logStream,
          options: { cwd: ctx.workspacePath }
        });
        console.log("Done running npm init");
        ctx.logger.info(`Done running npm init`);
      } catch (err) {
        console.error(err);
        ctx.logger.error(err);
        throw err;
      }
    }
  });
}

function createNpmInstallAction() {
  return pluginScaffolderBackend.createTemplateAction({
    id: "npm:install",
    description: "Runs npm install quietly with the given package name",
    supportsDryRun: true,
    schema: {
      input: {
        type: "object",
        required: ["packageToInstall"],
        properties: {
          packageToInstall: {
            title: "Name of package to install",
            description: "Name of package to install",
            type: "string"
          }
        }
      }
    },
    async handler(ctx) {
      try {
        console.log(`Running npm install in ${ctx.workspacePath}`);
        ctx.logger.info(`Running npm install in ${ctx.workspacePath}`);
        const npm = getNpmCommand(ctx);
        await pluginScaffolderBackend.executeShellCommand({
          command: npm,
          args: ["install", ctx.input.packageToInstall],
          logStream: ctx.logStream,
          options: { cwd: ctx.workspacePath }
        });
        console.log("Done running npm install");
        ctx.logger.info(`Done running npm install`);
      } catch (err) {
        console.error(err);
        ctx.logger.error(err);
        throw err;
      }
    }
  });
}

function createNpmConfigAction() {
  return pluginScaffolderBackend.createTemplateAction({
    id: "npm:config",
    description: "Runs npm config with the given arguments in the task workspace directory",
    supportsDryRun: true,
    schema: {
      input: {
        type: "object",
        required: ["arguments"],
        properties: {
          arguments: {
            title: "Arguments",
            description: "The arguments to pass to the npm config command",
            type: "array",
            items: {
              type: "string"
            }
          }
        }
      }
    },
    async handler(ctx) {
      try {
        console.log(`Running npm config in ${ctx.workspacePath}`);
        ctx.logger.info(`Running npm config in ${ctx.workspacePath}`);
        ctx.logger.info(`Input: ${ctx.input.arguments}`);
        const npm = getNpmCommand(ctx);
        ctx.logger.info(
          `OS platform is ${process.platform}, using '${npm}' as command`
        );
        await pluginScaffolderBackend.executeShellCommand({
          command: npm,
          args: ["config", ...ctx.input.arguments],
          logStream: ctx.logStream,
          options: { cwd: ctx.workspacePath }
        });
        console.log("Done running npm config");
        ctx.logger.info(`Done running npm config`);
      } catch (err) {
        console.error(err);
        ctx.logger.error(err);
        throw err;
      }
    }
  });
}

exports.createNpmConfigAction = createNpmConfigAction;
exports.createNpmExecAction = createNpmExecAction;
exports.createNpmInitAction = createNpmInitAction;
exports.createNpmInstallAction = createNpmInstallAction;
//# sourceMappingURL=index.cjs.js.map
